@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Net::Curl;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use constant
 	can_asynchdns => ( ( Net::Curl::version_info()->{features}
@@ -19,7 +19,6 @@ my @backends = (
 	# backends we support directly
 	EV => 'EV',
 	Irssi => 'Irssi',
-	POE => 'POE::Kernel',
 	AnyEvent => 'AnyEvent',
 
 	# AnyEvent supports some implementations we don't
@@ -34,7 +33,8 @@ my @backends = (
 
 	# some POE::Loop::* implementations,
 	# AnyEvent is preffered as it gives us a more
-	# direct access to those backends
+	# direct access to most backends
+	POE => 'POE::Kernel',
 	POE => 'Event',
 	POE => 'Event::Lib',
 	POE => 'Glib',
@@ -46,7 +46,7 @@ my @backends = (
 	# forced backends: try to load if nothing better detected
 	EV => undef, # most efficient implementation
 	AnyEvent => undef, # AnyEvent may have some nice alternative
-	Perl => undef, # will work everywhere and much faster than POE
+	Select => undef, # will work everywhere and much faster than POE
 );
 
 
@@ -184,21 +184,30 @@ order):
 
 =over
 
+=item EV
+
+Awesome and very efficient. Use it whenever you can.
+
 =item Irssi
 
-Will be used if Irssi has been loaded. Does not support loop(), the function
+Will be used if L<Irssi> has been loaded. Does not support loop(), the function
 will issue a warning and won't block.
 
 =item AnyEvent
 
-Will be used if AnyEvent has been loaded. In most cases you will already have
+Will be used if L<AnyEvent> has been loaded. In most cases you will already have
 a looping mechanism on your own, but you can call loop() if you don't need
 anything better.
 
-=item Perl
+=item POE
 
-Direct loop implementation in perl. Will be used if no other backend has been
-found. You must call loop() to get anything done.
+Used under L<POE>, only if no other backend could be detected. Slooow, avoid it.
+If you're using L<POE> try L<POE::Loop::EV>.
+
+=item Select
+
+Direct loop implementation using perl's builtin select. Will be used if no
+other backend has been found. You must call loop() to get anything done.
 
 =back
 
