@@ -3,18 +3,18 @@ package Net::Curl::Simple::Coro;
 use strict;
 use warnings;
 {
-	package Net::Curl::Simple::Async::Perl;
+	package Net::Curl::Simple::Async::Select;
 	use Coro::Select qw(select);
-	use Net::Curl::Simple::Async::Perl;
+	use Net::Curl::Simple::Async::Select;
 }
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 sub _perform($)
 {
 	my $easy = shift;
 	my $multi = $easy->{multi}
-		||= Net::Curl::Simple::Async::Perl->new();
+		||= Net::Curl::Simple::Async::Select->new();
 
 	$multi->add_handle( $easy );
 	$multi->loop();
@@ -34,8 +34,8 @@ Net::Curl::Simple::Coro - Coro integration for blocking Net::Curl requests
 
  my $c = async {
      Net::Curl::Simple->new()->get( $uri, \&finished );
-	 # this will be executed after finishing request
-	 ...
+     # this will be executed after finishing request
+     ...
  };
 
  Net::Curl::Simple->new()->get( $uri2, \&finished );
